summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--pkgs/development/libraries/libnotify/default.nix21
1 files changed, 9 insertions, 12 deletions
diff --git a/pkgs/development/libraries/libnotify/default.nix b/pkgs/development/libraries/libnotify/default.nix
index c26a64ec804..41a9cf518e4 100644
--- a/pkgs/development/libraries/libnotify/default.nix
+++ b/pkgs/development/libraries/libnotify/default.nix
@@ -1,27 +1,24 @@
-{ stdenv, fetchurl, pkgconfig, automake, autoconf, libtool
-, glib, gdk_pixbuf, gobjectIntrospection, autoreconfHook }:
+{ stdenv, fetchurl, pkgconfig, autoreconfHook
+, glib, gdk_pixbuf, gobjectIntrospection }:
 
 stdenv.mkDerivation rec {
   ver_maj = "0.7";
-  ver_min = "6";
+  ver_min = "7";
   name = "libnotify-${ver_maj}.${ver_min}";
 
   src = fetchurl {
     url = "mirror://gnome/sources/libnotify/${ver_maj}/${name}.tar.xz";
-    sha256 = "0dyq8zgjnnzcah31axnx6afb21kl7bks1gvrg4hjh3nk02j1rxhf";
+    sha256 = "017wgq9n00hx39n0hm784zn18hl721hbaijda868cm96bcqwxd4w";
   };
 
-  # see Gentoo ebuild - we don't need to depend on gtk+(2/3)
-  preAutoreconf = ''
-    sed -i -e 's:noinst_PROG:check_PROG:' tests/Makefile.am || die
-    sed -i -e '/PKG_CHECK_MODULES(TESTS/d' configure.ac || die
-  '';
+  # disable tests as we don't need to depend on gtk+(2/3)
+  configureFlags = [ "--disable-tests" ];
 
-  buildInputs = [ pkgconfig automake autoconf autoreconfHook
-                  libtool glib gdk_pixbuf gobjectIntrospection ];
+  nativeBuildInputs = [ pkgconfig autoreconfHook ];
+  buildInputs = [ glib gdk_pixbuf gobjectIntrospection ];
 
   meta = {
-    homepage = http://galago-project.org/; # very obsolete but found no better
+    homepage = https://developer.gnome.org/notification-spec/;
     description = "A library that sends desktop notifications to a notification daemon";
     platforms = stdenv.lib.platforms.unix;
   };